
# Class: prefix


prefix URI tuple

URI: [linkml:Prefix](https://w3id.org/linkml/Prefix)


[![img](images/Prefix.svg)](images/Prefix.svg)

## Referenced by Class

 *  **[SchemaDefinition](SchemaDefinition.md)** *[prefixes](prefixes.md)*  <sub>0..\*</sub>  **[Prefix](Prefix.md)**

## Attributes


### Own

 * [prefix_prefix](prefix_prefix.md)  <sub>1..1</sub>
     * Description: the nsname (sans ':' for a given prefix)
     * Range: [Ncname](types/Ncname.md)
 * [prefix_reference](prefix_reference.md)  <sub>1..1</sub>
     * Description: A URI associated with a given prefix
     * Range: [Uri](types/Uri.md)
